@@ -106,6 +106,7 @@ typedef struct {
 	gchar *login;
 	gchar *password;
 	gboolean persist;
+	gboolean noauth;
 	gchar *serial_port;
 	gchar *wvsection;
 	gboolean stupid;
@@ -113,6 +114,8 @@ typedef struct {
 	gchar *dns1;
 	gchar *dns2;
 	gchar *ppp_options;
+	gint volume;
+	gchar *dial_command;
 
 	/* PtP (PLIP) */
 	gchar *remote_address;
